/*
 * Copyright 2018 The Feast Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package feast.core.job;

import feast.core.model.JobInfo;
import java.nio.file.Path;

public interface JobManager {

  /**
   * Start an ingestion job.
   *
   * @param name job name
   * @param workspace containing specifications for running the job
   * @return job runner specific job id
   */
  String startJob(String name, Path workspace);

  /**
   * Update already running job with new set of features to ingest.
   *
   * @param jobInfo jobInfo of target job to change
   * @return job runner specific job id
   */
  String updateJob(JobInfo jobInfo, Path workspace);

  /**
   * Abort a job given runner-specific job ID.
   *
   * @param extId runner specific job id.
   */
  void abortJob(String extId);

}
